from plonehrm.notifications.interfaces import IHRMModuleEvent
from plonehrm.notifications.interfaces import IHRMEmailer


class IAbsenceEvent(IHRMModuleEvent):
    pass


class IAbsenceEmailer(IHRMEmailer):
    pass



from plonehrm.absence import AbsenceMessageFactory as _
from plonehrm.absence.interfaces import INote
from zope.component import adapts


class NextActionValidator(object):
    adapts(INote)

    def __init__(self, context):
        self.context = context

    def __call__(self, request):
        """If the next contact date is selected, we need the next action text.
        """
        if request.form.get('nextContactDate_year', '0000') == '0000':
            return None
        if request.form['nextAction']:
            return None
        return {'nextAction':
                _(u'When the next action date is set, the next action '
                  u'text is mandatory.')}



__author__ = """Jean-Paul Ladage <j.ladage@zestsoftware.nl>"""
__docformat__ = 'plaintext'

import logging
from DateTime import DateTime
from zope.interface import implements

from Products.CMFCore.utils import getToolByName
from Products.Archetypes import atapi
from Products.Archetypes.interfaces import IBaseContent
from Products.plonehrm.interfaces import IEmployeeModule
from plonehrm.absence import config
from plonehrm.absence.interfaces import IEvaluationInterview

from plonehrm.absence import AbsenceMessageFactory as _

logger = logging.getLogger('plonehrm.absence')

schema = atapi.Schema((
    atapi.StringField(
        name='template',
        widget=atapi.SelectionWidget(
            format='select',
            condition='not:object/template_chosen',
            label=_(u'template', default=u'Template'),
            ),
        required=1,
        vocabulary='_templates'
        ),
    atapi.DateTimeField(
        name='date',
        default_method=DateTime,
        widget=atapi.CalendarWidget(
            label=_(u'label_main_date', default=u'Date'),
            )
        ),
    atapi.TextField(
        'text',
        required=False,
        seachable=False,
        primary=True,
        default_output_type = 'text/x-html-safe',
        widget = atapi.RichWidget(
            description = '',
            label = _(u'label_body_text', default=u'Body Text'),
            rows = 25,
            condition='object/template_chosen'
            ),
        ),
    atapi.LinesField(
        name='improvementAreas',
        widget=atapi.LinesWidget(
            condition='object/template_chosen',
            label=_(u'label_improvementAreas', default=u'Improvement areas'),
            )
        ),
    ))

Interview_schema = atapi.BaseSchema.copy() + schema.copy()

for schema_key in Interview_schema.keys():
    if not Interview_schema[schema_key].schemata == 'default':
        Interview_schema[schema_key].widget.visible={'edit':'invisible',
                                                     'view':'invisible'}


class EvaluationInterview(atapi.BaseContent):
    """
    """
    __implements__ = (atapi.BaseContent.__implements__, )
    implements(IEmployeeModule, IBaseContent, IEvaluationInterview)
    _at_rename_after_creation = True
    schema = Interview_schema

    # plonehrm.absence wants to know what the main date is:
    main_date = atapi.ATDateTimeFieldProperty('date')

    def _templates(self):
        """
        """
        absencetool = getToolByName(self, 'portal_absence', None)
        if absencetool is None:
            return []
        else:
            items = [(item.id, item.Title())
                     for item in absencetool.listTemplates()]
            return atapi.DisplayList(items)

    def template_chosen(self):
        """Determine if the template (a string) has been chosen yet.
        """
        return len(self.template) > 0


atapi.registerType(EvaluationInterview, config.PROJECTNAME)



from DateTime import DateTime
from Products.Archetypes import atapi
from Products.ATContentTypes.content.file import ATFile
from Products.ATContentTypes.content.file import ATFileSchema
from Products.ATContentTypes.content import schemata

from plonehrm.absence.config import PROJECTNAME
from plonehrm.absence import AbsenceMessageFactory as _

schema = atapi.Schema((
        atapi.DateTimeField(
            name='fileDate',
            required=True,
            default_method=DateTime,
            widget=atapi.CalendarWidget(
                label=_(u'label_file_date', default=u'File date'),
                show_hm = False,
                )
            ),

        ))

AbsenceFileSchema = ATFileSchema.copy() + schema

AbsenceFileSchema['title'].storage = atapi.AnnotationStorage()
AbsenceFileSchema['description'].storage = atapi.AnnotationStorage()
schemata.finalizeATCTSchema(AbsenceFileSchema)

for schema_key in AbsenceFileSchema.keys():
    if not AbsenceFileSchema[schema_key].schemata == 'default':
        AbsenceFileSchema[schema_key].widget.visible={'edit':'invisible',
                                                      'view':'invisible'}


class AbsenceFile(ATFile):

    schema = AbsenceFileSchema
    meta_type = "AbsenceFile"

    title = atapi.ATFieldProperty('title')
    description = atapi.ATFieldProperty('description')
    file_date = atapi.ATDateTimeFieldProperty('fileDate')
    main_date = atapi.ATDateTimeFieldProperty('fileDate')


atapi.registerType(AbsenceFile, PROJECTNAME)
